/*
   Name:    "ShowCount-oo.rex"

   Invoke:  "java com.ibm.bsf.Main -lang rexx -in ShowCount-oo.rex"
                or
            "java com.ibm.bsf.Main            -in ShowCount-oo.rex"
                or
            "rexxj Showcount-oo.rex"
                or
            "rexx Showcount-oo.rex"

   Purpose:  create a little resizable window with a push button to count and reveal
             the number of times the button was pressed

   Needs:    IBM's "Bean Scripting Framework" (BSF)
             (cf. "http://oss.software.ibm.com/developerworks/projects/bsf")

             and the package "bsf4rexx"
             (cf. "http://nestroy.wi-inf.uni-essen.de/Forschung/rgf/Entwicklung.html")

   Date:    2001-04-30 (at the 12th International Rexx Symposium), 2003-01-23

   Author:   Rony G. Flatscher, University of Essen, WU Wien University,
             derived from Peter Kalender's work for the "Essener Ski Seminar",
             University of Essen (Oct 2000 to Feb 2001)
             (cf. "http://nestroy.wi-inf.uni-essen.de/Lv/seminare/ws0001/index-e.html");
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

.bsf~import("awtFrame",  "java.awt.Frame")
.bsf~import("awtButton", "java.awt.Button")
.bsf~import("awtLabel",  "java.awt.Label")

win=.awtFrame~new("string", "Show Count")
win~bsf.addEventListener('window', 'windowClosing', '.bsf~exit')

but=.awtButton~new("string", "Press me!")
but~bsf.addEventListener('action', '', 'call ShowSize')

lab=.awtLabel~new ~~setAlignment('I', 1)

win ~~add("string", "Center", "Object", lab) ~~add("str", "South", "Obj", but)
win ~~pack ~~show ~~toFront

i=0             /* set counter to 0     */

do forever
   a = bsf("pollEventText")     /* wait for an eventText to be sent     */
   say "received the following eventText: ["a"]"
   interpret a                  /* execute as a Rexx program    */
   if result= "SHUTDOWN, REXX !" then leave     /* JVM will be shutdown in 1/10sec      */
end

exit

        /* show the actual number of times, you pressed the button      */
ShowSize:
   i=i+1
   lab~setText('str', "Press #" i)
   return

::requires "BSF.cls"    -- get access to the Object Rexx support enhancement
